@@ -1,17 +1,17 @@
+import logging
 import os
 import re
 import subprocess
-import logging
 
 logger = logging.getLogger('giza.content.post.latex')
 
-from giza.command import command
-
-from giza.files import (create_link, copy_if_needed,
+from giza.content.helper import edition_check
+from giza.tools.command import command
+from giza.tools.serialization import ingest_yaml_list
+from giza.tools.strings import hyph_concat
+from giza.tools.transformation import munge_page
+from giza.tools.files import (create_link, copy_if_needed,
                         decode_lines_from_file, encode_lines_to_file)
-from giza.serialization import ingest_yaml_list
-from giza.transformation import munge_page
-from giza.strings import hyph_concat
 
 #################### PDFs from Latex Produced by Sphinx  ####################
 
@@ -60,6 +60,9 @@ def pdf_tasks(sconf, conf, app):
     link_app = app.add('app')
 
     for i in conf.system.files.data.pdfs:
+        if edition_check(i, conf) is False:
+            continue
+
         i = i.dict()
         tagged_name = i['output'][:-4] + '-' + i['tag']
         deploy_fn = tagged_name + '-' + conf.git.branches.current + '.pdf'
