@@ -12,7 +12,8 @@ from giza.tools.serialization import ingest_yaml_list, dict_from_list
 
 @argh.arg('--target', '-t', nargs='*', dest='push_targets')
 @argh.arg('--dry-run', '-d', action='store_true', dest='dry_run')
-def deploy(args):
+@argh.named('deploy')
+def main(args):
     c = fetch_config(args)
     app = BuildApp(c)
 
@@ -23,7 +24,8 @@ def deploy(args):
 @argh.arg('--language', '-l', nargs='*',dest='languages_to_build')
 @argh.arg('--builder', '-b', nargs='*', default='html')
 @argh.arg('--serial_sphinx', action='store_true', default=False)
-def push(args):
+@argh.named('push')
+def publish_and_deploy(args):
     c = fetch_config(args)
     app = BuildApp(c)
 
@@ -31,7 +33,7 @@ def push(args):
     if sphinx_ret == 0 or c.runstate.force is True:
         deploy_worker(c, app)
     else:
-        logger.warning('a sphinx build failed, and build not forced. not deploying.')
+        logger.warning(sphinx_ret + ' sphinx build(s) failed, and build not forced. not deploying.')
 
 def deploy_worker(c, app):
     pconf = c.system.files.data.push
